diff --git a/configure.ac b/configure.ac
index 839d012..ceac54d 100644
--- a/configure.ac
+++ b/configure.ac
@@ -86,6 +86,12 @@ AS_IF([test "x$with_conf" != xno], [SYSCONFIG="${with_conf}"])
 
 CPPFLAGS="${CPPFLAGS} -DCONF_DIR='\"${SYSCONFIG}\"'"
 
+AC_ARG_ENABLE([tests], AC_HELP_STRING([--disable-tests],[Disable internal tests support]),
+		[with_tests=$enableval],[with_tests=yes])
+AM_CONDITIONAL(ENABLE_TESTS, [test "x$with_tests" = "xyes"])
+if test "x$with_tests" = "xyes"; then
+	AC_DEFINE(ENABLE_TESTS, 1, [Enable internal tests support])
+fi
 
 AC_ARG_ENABLE([btrfs], AC_HELP_STRING([--disable-btrfs],[Disable Btrfs internal snapshots support]),
 		[with_btrfs=$enableval],[with_btrfs=yes])
diff --git a/testsuite-cmp/Makefile.am b/testsuite-cmp/Makefile.am
index 81104bf..9c29477 100644
--- a/testsuite-cmp/Makefile.am
+++ b/testsuite-cmp/Makefile.am
@@ -2,6 +2,7 @@
 # Makefile.am for snapper/testsuite-cmp
 #
 
+if ENABLE_TESTS
 AM_CPPFLAGS = -I$(top_srcdir)
 AM_LDFLAGS = -lboost_system
 
@@ -15,3 +16,4 @@ cmp_SOURCES = cmp.cc
 
 EXTRA_DIST = $(noinst_SCRIPTS)
 
+endif
diff --git a/testsuite-real/Makefile.am b/testsuite-real/Makefile.am
index 717313a..527843d 100644
--- a/testsuite-real/Makefile.am
+++ b/testsuite-real/Makefile.am
@@ -2,6 +2,7 @@
 # Makefile.am for snapper/testsuite-real
 #
 
+if ENABLE_TESTS
 CXXFLAGS += -std=gnu++0x
 
 AM_CPPFLAGS = -I$(top_srcdir)
@@ -53,3 +54,4 @@ ug_tests_SOURCES = ug-tests.cc
 
 EXTRA_DIST = $(test_DATA) $(test_SCRIPTS)
 
+endif
diff --git a/testsuite/Makefile.am b/testsuite/Makefile.am
index d7e30b8..72ef5ee 100644
--- a/testsuite/Makefile.am
+++ b/testsuite/Makefile.am
@@ -2,6 +2,7 @@
 # Makefile.am for snapper/testsuite
 #
 
+if ENABLE_TESTS
 AM_CPPFLAGS = -I$(top_srcdir) $(DBUS_CFLAGS)
 
 LDADD = ../snapper/libsnapper.la ../dbus/libdbus.la -lboost_unit_test_framework
@@ -40,3 +41,4 @@ json_formatter_test_LDADD = -lboost_unit_test_framework ../client/utils/libutils
 getopts_test_LDADD = -lboost_unit_test_framework ../client/utils/libutils.la
 
 lvm_utils_test_LDADD = -lboost_unit_test_framework ../snapper/libsnapper.la
+endif
diff --git a/zypp-plugin/testsuite/Makefile.am b/zypp-plugin/testsuite/Makefile.am
index 7b52e13..71cb545 100644
--- a/zypp-plugin/testsuite/Makefile.am
+++ b/zypp-plugin/testsuite/Makefile.am
@@ -1,3 +1,5 @@
+
+if ENABLE_TESTS
 if HAVE_ZYPP
 TEST_LOG_DRIVER = $(SHELL) tap-driver.sh
 
@@ -12,3 +14,4 @@ TESTS = $(check_SCRIPTS)
 
 EXTRA_DIST = $(check_SCRIPTS) $(noinst_SCRIPTS) $(noinst_DATA) tap-driver.sh
 endif
+endif
